pitchtools.sort_named_pitch_carriers_in_expr
============================================

.. autofunction:: abjad.tools.pitchtools.sort_named_pitch_carriers_in_expr.sort_named_pitch_carriers_in_expr
